#!/bin/ksh

if stty -a >/dev/null 2>&1
then
    interactive=true
else
    interactive=false
fi

number_field_definition=$1

if [[ -z $number_field_definition ]]
then
    print -u2 "error: no number field definition provided"
    exit 1
fi

if [[ ! -e $number_field_definition ]]
then
    print -u2 "error: cannot read number field definition"
    exit 1
fi

debug=0

degree=$( head -n 1 ${number_field_definition} | sed -e 's/].*$/]/' | awk -F, '{print NF}' )

prompt=${number_field_definition%%.*}

{
    cat ${number_field_definition}

    print

    while read
    do
	[[ $REPLY == @(quit) ]] && break
	print -r "$REPLY"
    done
} |

{
    [[ $interactive == true  ]] && echo "interactive=1"
    [[ $interactive == false ]] && echo "interactive=0"

    cat base-field.bc polynomial.bc

    auto-gen.bash $degree $prompt

    front-end.bash |&

    while read
    do
	expr=$REPLY

	passes=0

	while true
	do
	    print -p -- ${expr}
	    [[ $debug == 1 ]] && print "SENT <${expr}> to awk" > /dev/tty

	    unset expr

	    while read -pr result
	    do
		[[ $debug == 1 ]] && print "READ FROM AWK: <${result}>" > /dev/tty
		[[ $result == @(EXPR:*)  ]] && expr=${result}
		[[ $result == @(INSTR:*) && $debug == 0 ]] && print -r "${result#INSTR:}"
		[[ $result == @(DONE:*)  ]] && break
	    done

	    [[ -z $expr ]] && break

	    expr=${expr#EXPR:}
            passes=$((passes+1))
            [[ $(( passes % 100 )) -eq 0 ]] && print "AWK PASS: $passes" > /dev/tty
	done

    done
} |

bc -q
